Stan Math Library: stan/math/mix/mat.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mat.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_MIX_MAT_HPP
2 #define STAN_MATH_MIX_MAT_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <stan/math/fwd/scal/meta/is_fvar.hpp>
6 #include <stan/math/fwd/scal/meta/partials_type.hpp>
7
8 #include <stan/math/rev/core.hpp>
9 #include <stan/math/rev/scal/meta/is_var.hpp>
10 #include <stan/math/rev/scal/meta/partials_type.hpp>
11
12 #include <stan/math/prim/mat.hpp>
13 #include <stan/math/fwd/mat.hpp>
14 #include <stan/math/rev/mat.hpp>
15
16 #include <stan/math/mix/mat/fun/typedefs.hpp>
17
18 #include <stan/math/mix/mat/functor/derivative.hpp>
19 #include <stan/math/mix/mat/functor/finite_diff_grad_hessian.hpp>
20 #include <stan/math/mix/mat/functor/grad_hessian.hpp>
21 #include <stan/math/mix/mat/functor/grad_tr_mat_times_hessian.hpp>
22 #include <stan/math/mix/mat/functor/gradient_dot_vector.hpp>
23 #include <stan/math/mix/mat/functor/hessian.hpp>
24 #include <stan/math/mix/mat/functor/hessian_times_vector.hpp>
25 #include <stan/math/mix/mat/functor/partial_derivative.hpp>
26
27 #endif
core.hpp
core.hpp
typedefs.hpp
derivative.hpp
partials_type.hpp
grad_hessian.hpp
is_fvar.hpp
hessian.hpp
partial_derivative.hpp
mat.hpp
gradient_dot_vector.hpp
mat.hpp
partials_type.hpp
is_var.hpp
grad_tr_mat_times_hessian.hpp
mat.hpp
finite_diff_grad_hessian.hpp
hessian_times_vector.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.